@@ -12,3 +12,9 @@ except ImportError:
 
 from pip._vendor.requests.packages.urllib3.response import HTTPResponse
 from pip._vendor.requests.packages.urllib3.util import is_fp_closed
+
+# Replicate some six behaviour
+try:
+    text_type = (unicode,)
+except NameError:
+    text_type = (str,)
